"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTestModule = void 0;
const sleep_1 = require("../utils/sleep");
const send_callback_1 = require("../conformance-api/test-module/send-callback");
const logger_1 = require("../logger");
const final_statuses_1 = require("../constants/final-statuses");
const runTestModule = async (context, planId, testModule, runnerOptions, testOverride) => {
    const { authorizer, apiClient } = context;
    const { id } = await apiClient.createRunner(planId, testModule);
    let moduleInfo = await apiClient.getModuleInfo(id);
    logger_1.logger.info("Starting test polling");
    if (runnerOptions.bail && moduleInfo.status === "INTERRUPTED") {
        throw new Error("Test failed");
    }
    while (!final_statuses_1.finalStatuses.includes(moduleInfo.status)) {
        logger_1.logger.info("Test status", { status: moduleInfo.status });
        const { browser: { urls, visited }, } = await apiClient.getRunnerStatus(id);
        const runnerContext = {
            apiClient,
            status: moduleInfo.status,
            testId: id,
            testName: testModule.testModule,
            urls,
            visitedUrls: visited,
        };
        if (urls.length) {
            logger_1.logger.info("Visiting authorization URL");
            let interactionCookies = await authorizer.startInteraction(urls[0], runnerContext);
            await apiClient.visitUrl(id, urls[0]);
            logger_1.logger.info("Interaction started");
            interactionCookies = await authorizer.login(interactionCookies, runnerContext);
            logger_1.logger.info("Signed in successfully");
            let flow = "confirm";
            if (testOverride?.interactions?.length) {
                flow = testOverride.interactions.shift();
            }
            let callbackUrl;
            if (flow === "confirm") {
                callbackUrl = await authorizer.confirm(interactionCookies, runnerContext);
            }
            else {
                callbackUrl = await authorizer.abort(interactionCookies, runnerContext);
            }
            logger_1.logger.info(`Consent ${flow}ed`);
            await (0, send_callback_1.sendCallback)(callbackUrl);
        }
        if (testOverride?.custom) {
            const customOverrideResults = await Promise.all(testOverride.custom.map((custom) => custom(runnerContext)));
            // eslint-disable-next-line no-param-reassign
            testOverride.custom = testOverride.custom.filter((_, i) => !customOverrideResults[i]);
        }
        if (!final_statuses_1.finalStatuses.includes(moduleInfo.status)) {
            await (0, sleep_1.sleep)(3000);
            moduleInfo = await apiClient.getModuleInfo(id);
        }
    }
    logger_1.logger.info("Test finished", {
        id,
        name: testModule.testModule,
        status: moduleInfo.status,
        result: moduleInfo.result,
    });
};
exports.runTestModule = runTestModule;
//# sourceMappingURL=run-test-module.js.map