"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createApiClient = void 0;
const axios_1 = __importDefault(require("axios"));
const https_1 = __importDefault(require("https"));
const create_plan_1 = require("../conformance-api/plan/create-plan");
const get_plan_info_1 = require("../conformance-api/plan/get-plan-info");
const create_runner_1 = require("../conformance-api/runner/create-runner");
const get_runner_status_1 = require("../conformance-api/runner/get-runner-status");
const visit_url_1 = require("../conformance-api/runner/visit-url");
const get_module_info_1 = require("../conformance-api/test-module/get-module-info");
const send_callback_1 = require("../conformance-api/test-module/send-callback");
const get_runner_logs_1 = require("../conformance-api/runner/get-runner-logs");
const createApiClient = (options) => {
    const { conformanceUrl, token } = options;
    const httpsAgent = new https_1.default.Agent({
        rejectUnauthorized: false,
    });
    const axiosInstance = axios_1.default.create({
        baseURL: conformanceUrl,
        httpsAgent,
        ...(token && { headers: { Authorization: `Bearer ${token}` } }),
    });
    return {
        createPlan: (planOptions) => (0, create_plan_1.createPlan)(axiosInstance, planOptions),
        getPlanInfo: (planId) => (0, get_plan_info_1.getPlanInfo)(axiosInstance, planId),
        createRunner: (planId, planTestModule) => (0, create_runner_1.createRunner)(axiosInstance, planId, planTestModule),
        getRunnerStatus: (runnerId) => (0, get_runner_status_1.getRunnerStatus)(axiosInstance, runnerId),
        visitUrl: (runnerId, url) => (0, visit_url_1.visitUrl)(axiosInstance, runnerId, url),
        getModuleInfo: (runnerId) => (0, get_module_info_1.getModuleInfo)(axiosInstance, runnerId),
        sendCallback: (callbackUrl) => (0, send_callback_1.sendCallback)(callbackUrl),
        getRunnerLogs: (runnerId) => (0, get_runner_logs_1.getRunnerLogs)(axiosInstance, runnerId),
        axiosInstance,
    };
};
exports.createApiClient = createApiClient;
//# sourceMappingURL=create-api-client.js.map