"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterSkippedTests = void 0;
const logger_1 = require("../logger");
const filterSkippedTests = async (apiClient, modules, runnerOptions) => {
    const modulesInfo = await Promise.all(modules
        .filter(({ instances }) => !!instances.length)
        .map((module) => apiClient.getModuleInfo(module.instances.at(-1))));
    const skippedTests = modulesInfo
        .filter(({ status, result }) => status === "FINISHED" && result === "SKIPPED")
        .map(({ testName }) => testName);
    if (runnerOptions.skipPassed) {
        skippedTests.push(...modulesInfo
            .filter(({ result }) => result === "PASSED")
            .map(({ testName }) => testName));
        logger_1.logger.debug("Skipping passed tests");
    }
    if (runnerOptions.skipReview) {
        skippedTests.push(...modulesInfo
            .filter(({ status, result }) => status === "FINISHED" && result === "REVIEW")
            .map(({ testName }) => testName));
        logger_1.logger.debug("Skipping review tests");
    }
    if (runnerOptions.skipWarning) {
        skippedTests.push(...modulesInfo
            .filter(({ status, result }) => status === "FINISHED" && result === "WARNING")
            .map(({ testName }) => testName));
        logger_1.logger.debug("Skipping warning tests");
    }
    if (!skippedTests.length) {
        logger_1.logger.debug("No tests to skip");
        return modules;
    }
    logger_1.logger.debug(`Skipped ${skippedTests.length} tests`);
    return modules.filter(({ testModule }) => !skippedTests.includes(testModule));
};
exports.filterSkippedTests = filterSkippedTests;
//# sourceMappingURL=filter-skipped-tests.js.map